sepa.Account (Bank account) — amici1

# `sepa.Account` (Bank account)

Account(id, partner, iban, bic, remark, primary)

Master tables : sepa.Accounts (Bank accounts)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Partner (partner) : Partner

- IBAN (iban) : See `<lino_xl.lib.sepa.fields.IBANField: iban>`.

- BIC (bic) : See `<lino_xl.lib.sepa.fields.BICField: bic>`.

- Remark (remark) : See `<django.db.models.fields.CharField: remark>`.

- Primary (primary) : Enabling this field will automatically disable any previous primary account and update the partner’s IBAN and BIC

- Statements (statements) : A virtual field which displays the date of the last imported statement for this account. Clicking on this date will open the B2C account <lino_xl.lib.b2c.models.Account> with same IBAN number.

- Name (name_column) : See `lino_xl.lib.sepa.models.Account.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.sepa.models.Account.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.sepa.models.Account.overview`.

Referenced from ledger.Journal.sepa_account

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
partner | Partner | Partner
iban | IBAN |
bic | BIC |
remark | Remark |
primary | Primary | Enabling this field will automatically disable any previous primary account and update the partner’s IBAN and BIC
statements | Statements | A virtual field which displays the date of the last imported statement for this account. Clicking on this date will open the B2C account <lino_xl.lib.b2c.models.Account> with same IBAN number.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |